@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class SiteConfigsConfig(AppConfig):
-    name = "siteconfig"
+    name = "siteconfigs"
