@@ -2,7 +2,7 @@
 
 # from django.conf import settings
 from django.db import models
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.utils.text import slugify
 
 # from django.urls import reverse
